"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class S3APIGetObjectResponse(google.protobuf.message.Message):
    """Represents a response of the get object request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ETAG_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    ACCEPT_RANGES_FIELD_NUMBER: builtins.int
    CACHE_CONTROL_FIELD_NUMBER: builtins.int
    CONTENT_DISPOSITION_FIELD_NUMBER: builtins.int
    CONTENT_ENCODING_FIELD_NUMBER: builtins.int
    CONTENT_LANGUAGE_FIELD_NUMBER: builtins.int
    CONTENT_LENGTH_FIELD_NUMBER: builtins.int
    CONTENT_RANGE_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    EXPIRES_AT_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_AT_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    STORAGE_CLASS_FIELD_NUMBER: builtins.int
    SERVER_SIDE_ENCRYPTION_FIELD_NUMBER: builtins.int
    SSE_KMS_KEY_ID_FIELD_NUMBER: builtins.int
    OBJECT_LOCK_MODE_FIELD_NUMBER: builtins.int
    OBJECT_LOCK_RETAIN_UNTIL_DATE_FIELD_NUMBER: builtins.int
    OBJECT_LOCK_LEGAL_HOLD_STATUS_FIELD_NUMBER: builtins.int
    etag: builtins.str
    """MD5 hash of the object."""
    request_id: builtins.str
    """Unique request ID."""
    accept_ranges: builtins.str
    """Indicates that a range of bytes was specified in the request."""
    cache_control: builtins.str
    """Specifies caching behavior along the request/reply chain."""
    content_disposition: builtins.str
    """Specifies presentational information for the object."""
    content_encoding: builtins.str
    """Indicates what content encodings have been applied to the object."""
    content_language: builtins.str
    """The language the content is in."""
    content_length: builtins.int
    """Size of the body in bytes."""
    content_range: builtins.str
    """The portion of the object returned in the response."""
    content_type: builtins.str
    """A standard MIME type describing the format of the object data."""
    version_id: builtins.str
    """Version ID of the object."""
    storage_class: builtins.str
    """Provides storage class information of the object."""
    server_side_encryption: builtins.str
    """Encryption algorithm used to encrypt the object."""
    sse_kms_key_id: builtins.str
    """ID of the key KMS."""
    object_lock_mode: builtins.str
    """Type of retention put on the object."""
    object_lock_legal_hold_status: builtins.str
    """Type of legal hold put on the object"""
    @property
    def expires_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The date and time at which the object is no longer cacheable."""

    @property
    def last_modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Date and time when the object was last modified."""

    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Object user-defined metadata."""

    @property
    def object_lock_retain_until_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Date and time until which the object is retained"""

    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        request_id: builtins.str = ...,
        accept_ranges: builtins.str = ...,
        cache_control: builtins.str = ...,
        content_disposition: builtins.str = ...,
        content_encoding: builtins.str = ...,
        content_language: builtins.str = ...,
        content_length: builtins.int = ...,
        content_range: builtins.str = ...,
        content_type: builtins.str = ...,
        version_id: builtins.str = ...,
        expires_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        storage_class: builtins.str = ...,
        server_side_encryption: builtins.str = ...,
        sse_kms_key_id: builtins.str = ...,
        object_lock_mode: builtins.str = ...,
        object_lock_retain_until_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        object_lock_legal_hold_status: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expires_at", b"expires_at", "last_modified_at", b"last_modified_at", "object_lock_retain_until_date", b"object_lock_retain_until_date"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["accept_ranges", b"accept_ranges", "cache_control", b"cache_control", "content_disposition", b"content_disposition", "content_encoding", b"content_encoding", "content_language", b"content_language", "content_length", b"content_length", "content_range", b"content_range", "content_type", b"content_type", "etag", b"etag", "expires_at", b"expires_at", "last_modified_at", b"last_modified_at", "metadata", b"metadata", "object_lock_legal_hold_status", b"object_lock_legal_hold_status", "object_lock_mode", b"object_lock_mode", "object_lock_retain_until_date", b"object_lock_retain_until_date", "request_id", b"request_id", "server_side_encryption", b"server_side_encryption", "sse_kms_key_id", b"sse_kms_key_id", "storage_class", b"storage_class", "version_id", b"version_id"]) -> None: ...

global___S3APIGetObjectResponse = S3APIGetObjectResponse

@typing.final
class S3APIPutObjectResponse(google.protobuf.message.Message):
    """Represents a response of the put object request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    etag: builtins.str
    """MD5 hash of the object."""
    request_id: builtins.str
    """Unique request ID."""
    version_id: builtins.str
    """Version ID of the object."""
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        request_id: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["etag", b"etag", "request_id", b"request_id", "version_id", b"version_id"]) -> None: ...

global___S3APIPutObjectResponse = S3APIPutObjectResponse

@typing.final
class S3APIDeleteObjectResponse(google.protobuf.message.Message):
    """Represents a response of the delete object request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    """Unique request ID."""
    version_id: builtins.str
    """Version ID of the object."""
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["request_id", b"request_id", "version_id", b"version_id"]) -> None: ...

global___S3APIDeleteObjectResponse = S3APIDeleteObjectResponse

@typing.final
class CopyObjectResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_AT_FIELD_NUMBER: builtins.int
    etag: builtins.str
    """Returns the ETag of the new object."""
    @property
    def last_modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation date of the object."""

    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        last_modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["last_modified_at", b"last_modified_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["etag", b"etag", "last_modified_at", b"last_modified_at"]) -> None: ...

global___CopyObjectResult = CopyObjectResult

@typing.final
class S3APICopyObjectResponse(google.protobuf.message.Message):
    """Represents a response of the copy object request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COPY_OBJECT_RESULT_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    COPY_SOURCE_VERSION_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    """Unique request ID."""
    copy_source_version_id: builtins.str
    """Version ID of the source object that was copied."""
    version_id: builtins.str
    """Version ID of the newly created copy."""
    @property
    def copy_object_result(self) -> global___CopyObjectResult:
        """Container for all response elements."""

    def __init__(
        self,
        *,
        copy_object_result: global___CopyObjectResult | None = ...,
        request_id: builtins.str = ...,
        copy_source_version_id: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["copy_object_result", b"copy_object_result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["copy_object_result", b"copy_object_result", "copy_source_version_id", b"copy_source_version_id", "request_id", b"request_id", "version_id", b"version_id"]) -> None: ...

global___S3APICopyObjectResponse = S3APICopyObjectResponse

@typing.final
class SuccessfullyDeletedObject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    DELETE_MARKER_FIELD_NUMBER: builtins.int
    DELETE_MARKER_VERSION_ID_FIELD_NUMBER: builtins.int
    key: builtins.str
    """The name of the deleted object."""
    version_id: builtins.str
    """The version ID of the deleted object."""
    delete_marker: builtins.bool
    """Specifies whether the versioned object that was permanently deleted was (true) or was not (false) a delete marker."""
    delete_marker_version_id: builtins.str
    """The version ID of the delete marker created as a result of the DELETE operation."""
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        version_id: builtins.str = ...,
        delete_marker: builtins.bool = ...,
        delete_marker_version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["delete_marker", b"delete_marker", "delete_marker_version_id", b"delete_marker_version_id", "key", b"key", "version_id", b"version_id"]) -> None: ...

global___SuccessfullyDeletedObject = SuccessfullyDeletedObject

@typing.final
class DeleteObjectError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    key: builtins.str
    """The error key."""
    version_id: builtins.str
    """The version ID of the error."""
    code: builtins.str
    """The error code is a string that uniquely identifies an error condition."""
    msg: builtins.str
    """The error message contains a generic description of the error condition in English."""
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        version_id: builtins.str = ...,
        code: builtins.str = ...,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["code", b"code", "key", b"key", "msg", b"msg", "version_id", b"version_id"]) -> None: ...

global___DeleteObjectError = DeleteObjectError

@typing.final
class S3APIDeleteObjectsResponse(google.protobuf.message.Message):
    """Represents a response of the delete objects request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETED_FIELD_NUMBER: builtins.int
    ERRORS_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    """Unique request ID."""
    @property
    def deleted(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SuccessfullyDeletedObject]:
        """List of successfully deleted objects"""

    @property
    def errors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeleteObjectError]:
        """List of objects that attempted to be deleted but encountered an error"""

    def __init__(
        self,
        *,
        deleted: collections.abc.Iterable[global___SuccessfullyDeletedObject] | None = ...,
        errors: collections.abc.Iterable[global___DeleteObjectError] | None = ...,
        request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["deleted", b"deleted", "errors", b"errors", "request_id", b"request_id"]) -> None: ...

global___S3APIDeleteObjectsResponse = S3APIDeleteObjectsResponse

@typing.final
class S3APIPutObjectRetentionResponse(google.protobuf.message.Message):
    """Represents a response of the put object retention request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    """Unique request ID."""
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["request_id", b"request_id"]) -> None: ...

global___S3APIPutObjectRetentionResponse = S3APIPutObjectRetentionResponse

@typing.final
class ObjectLockRetention(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODE_FIELD_NUMBER: builtins.int
    RETAIN_UNTIL_DATE_FIELD_NUMBER: builtins.int
    mode: builtins.str
    """Indicates the Retention mode for the specified object."""
    @property
    def retain_until_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The date on which this object lock retention will expire."""

    def __init__(
        self,
        *,
        mode: builtins.str = ...,
        retain_until_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["retain_until_date", b"retain_until_date"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["mode", b"mode", "retain_until_date", b"retain_until_date"]) -> None: ...

global___ObjectLockRetention = ObjectLockRetention

@typing.final
class S3APIGetObjectRetentionResponse(google.protobuf.message.Message):
    """Represents a response of the get object retention request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    RETENTION_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    """Unique request ID."""
    @property
    def retention(self) -> global___ObjectLockRetention:
        """An object retention settings."""

    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
        retention: global___ObjectLockRetention | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["retention", b"retention"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["request_id", b"request_id", "retention", b"retention"]) -> None: ...

global___S3APIGetObjectRetentionResponse = S3APIGetObjectRetentionResponse

@typing.final
class S3APIPutObjectLegalHoldResponse(google.protobuf.message.Message):
    """Represents a response of the put object retention request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    """Unique request ID."""
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["request_id", b"request_id"]) -> None: ...

global___S3APIPutObjectLegalHoldResponse = S3APIPutObjectLegalHoldResponse

@typing.final
class ObjectLockLegalHold(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: builtins.str
    """Indicates whether the specified object has a legal hold in place."""
    def __init__(
        self,
        *,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

global___ObjectLockLegalHold = ObjectLockLegalHold

@typing.final
class S3APIGetObjectLegalHoldResponse(google.protobuf.message.Message):
    """Represents a response of the get object legal hold request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    LEGAL_HOLD_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    """Unique request ID."""
    @property
    def legal_hold(self) -> global___ObjectLockLegalHold:
        """The current legal hold status for the specified object."""

    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
        legal_hold: global___ObjectLockLegalHold | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["legal_hold", b"legal_hold"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["legal_hold", b"legal_hold", "request_id", b"request_id"]) -> None: ...

global___S3APIGetObjectLegalHoldResponse = S3APIGetObjectLegalHoldResponse

@typing.final
class S3APIPutObjectTaggingResponse(google.protobuf.message.Message):
    """Represents a response of put object tagging request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    """Unique request ID."""
    version_id: builtins.str
    """The versionId of the object the tag-set was added to."""
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["request_id", b"request_id", "version_id", b"version_id"]) -> None: ...

global___S3APIPutObjectTaggingResponse = S3APIPutObjectTaggingResponse

@typing.final
class ObjectTag(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: builtins.str
    """Key of the object tag."""
    value: builtins.str
    """Value of the object tag."""
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

global___ObjectTag = ObjectTag

@typing.final
class S3APIGetObjectTaggingResponse(google.protobuf.message.Message):
    """Represents a response of get object tagging request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    TAG_SET_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    """Unique request ID."""
    version_id: builtins.str
    """The versionId of the object for which you got the tagging information."""
    @property
    def tag_set(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ObjectTag]:
        """Contains the tag set."""

    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
        version_id: builtins.str = ...,
        tag_set: collections.abc.Iterable[global___ObjectTag] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["request_id", b"request_id", "tag_set", b"tag_set", "version_id", b"version_id"]) -> None: ...

global___S3APIGetObjectTaggingResponse = S3APIGetObjectTaggingResponse

@typing.final
class S3APIDeleteObjectTaggingResponse(google.protobuf.message.Message):
    """Represents a response of delete object tagging request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    """Unique request ID."""
    version_id: builtins.str
    """The versionId of the object the tag-set was removed from."""
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["request_id", b"request_id", "version_id", b"version_id"]) -> None: ...

global___S3APIDeleteObjectTaggingResponse = S3APIDeleteObjectTaggingResponse

@typing.final
class S3APIStartMultipartUploadResponse(google.protobuf.message.Message):
    """Represents a response of start multipart upload request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    UPLOAD_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    """Unique request ID."""
    bucket: builtins.str
    """The name of the bucket in which the initiated multipart upload was initiated."""
    key: builtins.str
    """Object key for which the multipart upload was initiated."""
    upload_id: builtins.str
    """The ID of the initiated multipart upload."""
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
        bucket: builtins.str = ...,
        key: builtins.str = ...,
        upload_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bucket", b"bucket", "key", b"key", "request_id", b"request_id", "upload_id", b"upload_id"]) -> None: ...

global___S3APIStartMultipartUploadResponse = S3APIStartMultipartUploadResponse

@typing.final
class S3APIUploadPartResponse(google.protobuf.message.Message):
    """Represents a response of upload part request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    """Unique request ID."""
    etag: builtins.str
    """MD5 hash of the object."""
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
        etag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["etag", b"etag", "request_id", b"request_id"]) -> None: ...

global___S3APIUploadPartResponse = S3APIUploadPartResponse

@typing.final
class S3APIListPartsResponse(google.protobuf.message.Message):
    """Represents a response of list parts request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    UPLOAD_ID_FIELD_NUMBER: builtins.int
    PART_NUMBER_MARKER_FIELD_NUMBER: builtins.int
    NEXT_PART_NUMBER_MARKER_FIELD_NUMBER: builtins.int
    MAX_PARTS_FIELD_NUMBER: builtins.int
    IS_TRUNCATED_FIELD_NUMBER: builtins.int
    PARTS_FIELD_NUMBER: builtins.int
    INITIATOR_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    STORAGE_CLASS_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    """The name of the bucket to which the multipart upload was initiated."""
    key: builtins.str
    """Object key for which the multipart upload was initiated."""
    upload_id: builtins.str
    """Upload ID identifying the multipart upload whose parts are being listed."""
    part_number_marker: builtins.str
    """When a list is truncated, this element specifies the last part in the list, as
    well as the value to use for the part-number-marker request parameter in a
    subsequent request.
    """
    next_part_number_marker: builtins.str
    """When a list is truncated, this element specifies the last part in the list, as
    well as the value to use for the part-number-marker request parameter in a
    subsequent request.
    """
    max_parts: builtins.int
    """Maximum number of parts that were allowed in the response."""
    is_truncated: builtins.bool
    """Indicates whether the returned list of parts is truncated."""
    storage_class: builtins.str
    """Class of storage used to store the uploaded object."""
    request_id: builtins.str
    """Unique request ID."""
    @property
    def parts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___S3APIPart]:
        """Container for elements related to a particular part."""

    @property
    def initiator(self) -> global___S3APIOwner:
        """Container element that identifies who initiated the multipart upload."""

    @property
    def owner(self) -> global___S3APIOwner:
        """Container element that identifies who initiated the multipart upload."""

    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        key: builtins.str = ...,
        upload_id: builtins.str = ...,
        part_number_marker: builtins.str = ...,
        next_part_number_marker: builtins.str = ...,
        max_parts: builtins.int = ...,
        is_truncated: builtins.bool = ...,
        parts: collections.abc.Iterable[global___S3APIPart] | None = ...,
        initiator: global___S3APIOwner | None = ...,
        owner: global___S3APIOwner | None = ...,
        storage_class: builtins.str = ...,
        request_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["initiator", b"initiator", "owner", b"owner"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bucket", b"bucket", "initiator", b"initiator", "is_truncated", b"is_truncated", "key", b"key", "max_parts", b"max_parts", "next_part_number_marker", b"next_part_number_marker", "owner", b"owner", "part_number_marker", b"part_number_marker", "parts", b"parts", "request_id", b"request_id", "storage_class", b"storage_class", "upload_id", b"upload_id"]) -> None: ...

global___S3APIListPartsResponse = S3APIListPartsResponse

@typing.final
class S3APIPart(google.protobuf.message.Message):
    """Container for elements related to a part."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PART_NUMBER_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_AT_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    part_number: builtins.int
    """Part number identifying the part. This is a positive integer between 1 and
    10,000.
    """
    size: builtins.int
    """Size in bytes of the uploaded part data."""
    etag: builtins.str
    """Entity tag returned when the part was uploaded."""
    @property
    def last_modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Date and time at which the part was uploaded."""

    def __init__(
        self,
        *,
        part_number: builtins.int = ...,
        last_modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        size: builtins.int = ...,
        etag: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["last_modified_at", b"last_modified_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["etag", b"etag", "last_modified_at", b"last_modified_at", "part_number", b"part_number", "size", b"size"]) -> None: ...

global___S3APIPart = S3APIPart

@typing.final
class S3APIAbortMultipartUploadResponse(google.protobuf.message.Message):
    """Represents a response of abort multipart upload request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    """Unique request ID."""
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["request_id", b"request_id"]) -> None: ...

global___S3APIAbortMultipartUploadResponse = S3APIAbortMultipartUploadResponse

@typing.final
class S3APICompleteMultipartUploadResponse(google.protobuf.message.Message):
    """Represents a response of complete multipart upload request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    """Unique request ID."""
    bucket: builtins.str
    """The name of the bucket that contains the newly created object."""
    key: builtins.str
    """The object key of the newly created object."""
    etag: builtins.str
    """Entity tag that identifies the newly created object's data."""
    location: builtins.str
    """The URI that identifies the newly created object."""
    version_id: builtins.str
    """Version ID of the newly created object, in case the bucket has versioning
    turned on.
    """
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
        bucket: builtins.str = ...,
        key: builtins.str = ...,
        etag: builtins.str = ...,
        location: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bucket", b"bucket", "etag", b"etag", "key", b"key", "location", b"location", "request_id", b"request_id", "version_id", b"version_id"]) -> None: ...

global___S3APICompleteMultipartUploadResponse = S3APICompleteMultipartUploadResponse

@typing.final
class S3APIListMultipartUploadsResponse(google.protobuf.message.Message):
    """Represents a response of list multipart uploads request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    KEY_MARKER_FIELD_NUMBER: builtins.int
    UPLOAD_ID_MARKER_FIELD_NUMBER: builtins.int
    NEXT_KEY_MARKER_FIELD_NUMBER: builtins.int
    NEXT_UPLOAD_ID_MARKER_FIELD_NUMBER: builtins.int
    DELIMITER_FIELD_NUMBER: builtins.int
    PREFIX_FIELD_NUMBER: builtins.int
    MAX_UPLOADS_FIELD_NUMBER: builtins.int
    IS_TRUNCATED_FIELD_NUMBER: builtins.int
    UPLOADS_FIELD_NUMBER: builtins.int
    COMMON_PREFIXES_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    """The name of the bucket to which the multipart upload was initiated."""
    key_marker: builtins.str
    """The key at or after which the listing began."""
    upload_id_marker: builtins.str
    """Upload ID after which listing began."""
    next_key_marker: builtins.str
    """When a list is truncated, this element specifies the value that should be used
    for the key-marker request parameter in a subsequent request.
    """
    next_upload_id_marker: builtins.str
    """When a list is truncated, this element specifies the value that should be used
    for the upload-id-marker request parameter in a subsequent request.
    """
    delimiter: builtins.str
    """Contains the delimiter you specified in the request."""
    prefix: builtins.str
    """When a prefix is provided in the request, this field contains the specified
    prefix.
    """
    max_uploads: builtins.int
    """Maximum number of multipart uploads that could have been included in the
    response.
    """
    is_truncated: builtins.bool
    """Indicates whether the returned list of multipart uploads is truncated."""
    request_id: builtins.str
    """Unique request ID."""
    @property
    def uploads(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___S3APIMultipartUpload]:
        """Container for elements related to a particular multipart upload."""

    @property
    def common_prefixes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """If you specify a delimiter in the request, then the result returns each
        distinct key prefix containing the delimiter in a CommonPrefixes element.
        """

    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        key_marker: builtins.str = ...,
        upload_id_marker: builtins.str = ...,
        next_key_marker: builtins.str = ...,
        next_upload_id_marker: builtins.str = ...,
        delimiter: builtins.str = ...,
        prefix: builtins.str = ...,
        max_uploads: builtins.int = ...,
        is_truncated: builtins.bool = ...,
        uploads: collections.abc.Iterable[global___S3APIMultipartUpload] | None = ...,
        common_prefixes: collections.abc.Iterable[builtins.str] | None = ...,
        request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bucket", b"bucket", "common_prefixes", b"common_prefixes", "delimiter", b"delimiter", "is_truncated", b"is_truncated", "key_marker", b"key_marker", "max_uploads", b"max_uploads", "next_key_marker", b"next_key_marker", "next_upload_id_marker", b"next_upload_id_marker", "prefix", b"prefix", "request_id", b"request_id", "upload_id_marker", b"upload_id_marker", "uploads", b"uploads"]) -> None: ...

global___S3APIListMultipartUploadsResponse = S3APIListMultipartUploadsResponse

@typing.final
class S3APIMultipartUpload(google.protobuf.message.Message):
    """Container for the MultipartUpload for the S3 object."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    UPLOAD_ID_FIELD_NUMBER: builtins.int
    INITIATOR_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    STORAGE_CLASS_FIELD_NUMBER: builtins.int
    INITIATED_AT_FIELD_NUMBER: builtins.int
    key: builtins.str
    """Key of the object for which the multipart upload was initiated."""
    upload_id: builtins.str
    """Upload ID that identifies the multipart upload."""
    storage_class: builtins.str
    """The class of storage used to store the object."""
    @property
    def initiator(self) -> global___S3APIOwner:
        """Identifies who initiated the multipart upload."""

    @property
    def owner(self) -> global___S3APIOwner:
        """Specifies the owner of the object that is part of the multipart upload."""

    @property
    def initiated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Date and time at which the multipart upload was initiated."""

    def __init__(
        self,
        *,
        key: builtins.str = ...,
        upload_id: builtins.str = ...,
        initiator: global___S3APIOwner | None = ...,
        owner: global___S3APIOwner | None = ...,
        storage_class: builtins.str = ...,
        initiated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["initiated_at", b"initiated_at", "initiator", b"initiator", "owner", b"owner"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["initiated_at", b"initiated_at", "initiator", b"initiator", "key", b"key", "owner", b"owner", "storage_class", b"storage_class", "upload_id", b"upload_id"]) -> None: ...

global___S3APIMultipartUpload = S3APIMultipartUpload

@typing.final
class S3APIOwner(google.protobuf.message.Message):
    """Container for the owner/initiator display name and ID."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Container for the ID of the owner/initiator."""
    display_name: builtins.str
    """Container for the display name of the owner/initiator."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        display_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["display_name", b"display_name", "id", b"id"]) -> None: ...

global___S3APIOwner = S3APIOwner

@typing.final
class S3APIUploadPartCopyResponse(google.protobuf.message.Message):
    """Response message for UploadPartCopy operation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_AT_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    etag: builtins.str
    """Entity tag of the object."""
    request_id: builtins.str
    """Unique request ID."""
    @property
    def last_modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Date and time at which the object was uploaded."""

    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        last_modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        request_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["last_modified_at", b"last_modified_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["etag", b"etag", "last_modified_at", b"last_modified_at", "request_id", b"request_id"]) -> None: ...

global___S3APIUploadPartCopyResponse = S3APIUploadPartCopyResponse

@typing.final
class S3APIListObjectsV2Response(google.protobuf.message.Message):
    """Represents a response of list objects v2 request to S3."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_TRUNCATED_FIELD_NUMBER: builtins.int
    CONTENTS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PREFIX_FIELD_NUMBER: builtins.int
    DELIMITER_FIELD_NUMBER: builtins.int
    MAX_KEYS_FIELD_NUMBER: builtins.int
    COMMON_PREFIXES_FIELD_NUMBER: builtins.int
    KEY_COUNT_FIELD_NUMBER: builtins.int
    CONTINUATION_TOKEN_FIELD_NUMBER: builtins.int
    NEXT_CONTINUATION_TOKEN_FIELD_NUMBER: builtins.int
    START_AFTER_FIELD_NUMBER: builtins.int
    REQUEST_ID_FIELD_NUMBER: builtins.int
    is_truncated: builtins.bool
    """A flag that indicates whether S3 returned all of the results that satisfied the search criteria."""
    name: builtins.str
    """The bucket name."""
    prefix: builtins.str
    """Keys that begin with the indicated prefix."""
    delimiter: builtins.str
    """Causes keys that contain the same string between the prefix and the first occurrence of the delimiter to be rolled up into a single result element in the CommonPrefixes collection."""
    max_keys: builtins.int
    """The maximum number of keys returned in the response body."""
    key_count: builtins.int
    """The number of keys returned with this request."""
    continuation_token: builtins.str
    """Indicates where in the bucket listing begins. This is only returned if a continuation token was used in the request."""
    next_continuation_token: builtins.str
    """If the response is truncated, S3 returns this continuation token, which you can use in the next request to fetch the next set of keys."""
    start_after: builtins.str
    """StartAfter is where you want S3 to start listing from. This is only returned if a start-after was used in the request."""
    request_id: builtins.str
    """Unique request ID."""
    @property
    def contents(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___S3APIObject]:
        """Metadata about each object returned."""

    @property
    def common_prefixes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___S3APICommonPrefix]:
        """All of the keys rolled up into a common prefix count as a single return when calculating the number of returns."""

    def __init__(
        self,
        *,
        is_truncated: builtins.bool = ...,
        contents: collections.abc.Iterable[global___S3APIObject] | None = ...,
        name: builtins.str = ...,
        prefix: builtins.str = ...,
        delimiter: builtins.str = ...,
        max_keys: builtins.int = ...,
        common_prefixes: collections.abc.Iterable[global___S3APICommonPrefix] | None = ...,
        key_count: builtins.int = ...,
        continuation_token: builtins.str = ...,
        next_continuation_token: builtins.str = ...,
        start_after: builtins.str = ...,
        request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["common_prefixes", b"common_prefixes", "contents", b"contents", "continuation_token", b"continuation_token", "delimiter", b"delimiter", "is_truncated", b"is_truncated", "key_count", b"key_count", "max_keys", b"max_keys", "name", b"name", "next_continuation_token", b"next_continuation_token", "prefix", b"prefix", "request_id", b"request_id", "start_after", b"start_after"]) -> None: ...

global___S3APIListObjectsV2Response = S3APIListObjectsV2Response

@typing.final
class S3APIObject(google.protobuf.message.Message):
    """Container for object metadata."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    STORAGE_CLASS_FIELD_NUMBER: builtins.int
    key: builtins.str
    """The object key."""
    etag: builtins.str
    """The entity tag is a hash of the object."""
    size: builtins.int
    """Size in bytes of the object."""
    storage_class: builtins.str
    """The class of storage used to store the object."""
    @property
    def last_modified(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Date and time the object was last modified."""

    @property
    def owner(self) -> global___S3APIOwner:
        """The owner of the object."""

    def __init__(
        self,
        *,
        key: builtins.str = ...,
        last_modified: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        etag: builtins.str = ...,
        size: builtins.int = ...,
        owner: global___S3APIOwner | None = ...,
        storage_class: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["last_modified", b"last_modified", "owner", b"owner"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["etag", b"etag", "key", b"key", "last_modified", b"last_modified", "owner", b"owner", "size", b"size", "storage_class", b"storage_class"]) -> None: ...

global___S3APIObject = S3APIObject

@typing.final
class S3APICommonPrefix(google.protobuf.message.Message):
    """Container for common prefix information."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREFIX_FIELD_NUMBER: builtins.int
    prefix: builtins.str
    """Container for the specified common prefix."""
    def __init__(
        self,
        *,
        prefix: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["prefix", b"prefix"]) -> None: ...

global___S3APICommonPrefix = S3APICommonPrefix



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cdn/v1/provider_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cdn/v1/provider_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/cdn/v1/provider_service.proto\x12\x13yandex.cloud.cdn.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"_\n\x17\x41\x63tivateProviderRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\rprovider_type\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\";\n\x18\x41\x63tivateProviderMetadata\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"@\n\x1dListActivatedProvidersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"3\n\x1eListActivatedProvidersResponse\x12\x11\n\tproviders\x18\x01 \x03(\t2\xe1\x02\n\x0fProviderService\x12\xb7\x01\n\x08\x41\x63tivate\x12,.yandex.cloud.cdn.v1.ActivateProviderRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*1\n\x18\x41\x63tivateProviderMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1f\"\x1a/cdn/v1/providers:activate:\x01*\x12\x93\x01\n\rListActivated\x12\x32.yandex.cloud.cdn.v1.ListActivatedProvidersRequest\x1a\x33.yandex.cloud.cdn.v1.ListActivatedProvidersResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/cdn/v1/providersBV\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cdn.v1.provider_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn'
  _globals['_ACTIVATEPROVIDERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_ACTIVATEPROVIDERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ACTIVATEPROVIDERREQUEST'].fields_by_name['provider_type']._loaded_options = None
  _globals['_ACTIVATEPROVIDERREQUEST'].fields_by_name['provider_type']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ACTIVATEPROVIDERMETADATA'].fields_by_name['folder_id']._loaded_options = None
  _globals['_ACTIVATEPROVIDERMETADATA'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTACTIVATEDPROVIDERSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTACTIVATEDPROVIDERSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_PROVIDERSERVICE'].methods_by_name['Activate']._loaded_options = None
  _globals['_PROVIDERSERVICE'].methods_by_name['Activate']._serialized_options = b'\262\322*1\n\030ActivateProviderMetadata\022\025google.protobuf.Empty\202\323\344\223\002\037\"\032/cdn/v1/providers:activate:\001*'
  _globals['_PROVIDERSERVICE'].methods_by_name['ListActivated']._loaded_options = None
  _globals['_PROVIDERSERVICE'].methods_by_name['ListActivated']._serialized_options = b'\202\323\344\223\002\023\022\021/cdn/v1/providers'
  _globals['_ACTIVATEPROVIDERREQUEST']._serialized_start=202
  _globals['_ACTIVATEPROVIDERREQUEST']._serialized_end=297
  _globals['_ACTIVATEPROVIDERMETADATA']._serialized_start=299
  _globals['_ACTIVATEPROVIDERMETADATA']._serialized_end=358
  _globals['_LISTACTIVATEDPROVIDERSREQUEST']._serialized_start=360
  _globals['_LISTACTIVATEDPROVIDERSREQUEST']._serialized_end=424
  _globals['_LISTACTIVATEDPROVIDERSRESPONSE']._serialized_start=426
  _globals['_LISTACTIVATEDPROVIDERSRESPONSE']._serialized_end=477
  _globals['_PROVIDERSERVICE']._serialized_start=480
  _globals['_PROVIDERSERVICE']._serialized_end=833
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.loadtesting.api.v1.agent.agent_pb2
import yandex.cloud.loadtesting.api.v1.agent.create_compute_instance_pb2
import yandex.cloud.loadtesting.api.v1.agent.log_settings_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateAgentRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_PARAMS_FIELD_NUMBER: builtins.int
    AGENT_VERSION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOG_SETTINGS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create an agent in."""
    name: builtins.str
    """Name of the agent.

    A created compute instance will have the same name.
    """
    description: builtins.str
    """Description of the agent.

    A created compute instance will have the same description.
    """
    agent_version: builtins.str
    """Version of the agent.

    If not provided, the most recent agent version will be used.
    """
    @property
    def compute_instance_params(self) -> yandex.cloud.loadtesting.api.v1.agent.create_compute_instance_pb2.CreateComputeInstance:
        """Parameters for compute instance to be created."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Agent labels as `key:value` pairs."""

    @property
    def log_settings(self) -> yandex.cloud.loadtesting.api.v1.agent.log_settings_pb2.LogSettings:
        """Agent log settings"""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        compute_instance_params: yandex.cloud.loadtesting.api.v1.agent.create_compute_instance_pb2.CreateComputeInstance | None = ...,
        agent_version: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        log_settings: yandex.cloud.loadtesting.api.v1.agent.log_settings_pb2.LogSettings | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["compute_instance_params", b"compute_instance_params", "log_settings", b"log_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["agent_version", b"agent_version", "compute_instance_params", b"compute_instance_params", "description", b"description", "folder_id", b"folder_id", "labels", b"labels", "log_settings", b"log_settings", "name", b"name"]) -> None: ...

global___CreateAgentRequest = CreateAgentRequest

@typing.final
class CreateAgentMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGENT_ID_FIELD_NUMBER: builtins.int
    agent_id: builtins.str
    """ID of the agent that is being created."""
    def __init__(
        self,
        *,
        agent_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["agent_id", b"agent_id"]) -> None: ...

global___CreateAgentMetadata = CreateAgentMetadata

@typing.final
class GetAgentRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGENT_ID_FIELD_NUMBER: builtins.int
    agent_id: builtins.str
    """ID of the agent to return."""
    def __init__(
        self,
        *,
        agent_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["agent_id", b"agent_id"]) -> None: ...

global___GetAgentRequest = GetAgentRequest

@typing.final
class DeleteAgentRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGENT_ID_FIELD_NUMBER: builtins.int
    agent_id: builtins.str
    """ID of the agent to delete."""
    def __init__(
        self,
        *,
        agent_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["agent_id", b"agent_id"]) -> None: ...

global___DeleteAgentRequest = DeleteAgentRequest

@typing.final
class DeleteAgentMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGENT_ID_FIELD_NUMBER: builtins.int
    agent_id: builtins.str
    """ID of the agent that is being deleted."""
    def __init__(
        self,
        *,
        agent_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["agent_id", b"agent_id"]) -> None: ...

global___DeleteAgentMetadata = DeleteAgentMetadata

@typing.final
class ListAgentsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list agents in."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListAgentsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the 
    [ListAgentsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters agents listed in the response.

    The filter expression may contain multiple field expressions joined by `AND`.
    The field expression must specify:
    1. The field name.
    2. An operator:
       - `=`, `!=`, `CONTAINS`, for single values.
       - `IN` or `NOT IN` for lists of values.
    3. The value. String values must be encosed in `"`, boolean values are {`true`, `false`}, timestamp values in ISO-8601.

    Currently supported fields:
    - `id` [yandex.cloud.loadtesting.api.v1.agent.Agent.id]
      - operators: `=`, `!=`, `IN`, `NOT IN`
    - `name` [yandex.cloud.loadtesting.api.v1.agent.Agent.name]
      - operators: `=`, `!=`, `IN`, `NOT IN`, `CONTAINS`

    Examples: 
    - `id IN ("1", "2", "3")`
    - `name CONTAINS "compute-agent-large" AND id NOT IN ("4", "5")`
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListAgentsRequest = ListAgentsRequest

@typing.final
class ListAgentsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGENTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListAgentsRequest.page_size], use `next_page_token` as the value
    for the [ListAgentsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def agents(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.loadtesting.api.v1.agent.agent_pb2.Agent]:
        """List of agents in the specified folder."""

    def __init__(
        self,
        *,
        agents: collections.abc.Iterable[yandex.cloud.loadtesting.api.v1.agent.agent_pb2.Agent] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["agents", b"agents", "next_page_token", b"next_page_token"]) -> None: ...

global___ListAgentsResponse = ListAgentsResponse

@typing.final
class UpdateAgentRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    AGENT_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_PARAMS_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    agent_id: builtins.str
    """ID of the agent to update."""
    name: builtins.str
    """New name of the agent."""
    description: builtins.str
    """New description of the agent."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the agent are going to be updated."""

    @property
    def compute_instance_params(self) -> yandex.cloud.loadtesting.api.v1.agent.create_compute_instance_pb2.CreateComputeInstance:
        """New parameters of compute instance managed by the agent."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """New labels of the agent."""

    def __init__(
        self,
        *,
        agent_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        compute_instance_params: yandex.cloud.loadtesting.api.v1.agent.create_compute_instance_pb2.CreateComputeInstance | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["compute_instance_params", b"compute_instance_params", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["agent_id", b"agent_id", "compute_instance_params", b"compute_instance_params", "description", b"description", "labels", b"labels", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateAgentRequest = UpdateAgentRequest

@typing.final
class UpdateAgentMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGENT_ID_FIELD_NUMBER: builtins.int
    agent_id: builtins.str
    """ID of the agent that is being updated."""
    def __init__(
        self,
        *,
        agent_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["agent_id", b"agent_id"]) -> None: ...

global___UpdateAgentMetadata = UpdateAgentMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Format:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Format.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FORMAT_UNSPECIFIED: _Format.ValueType  # 0
    VERSION_11: _Format.ValueType  # 1
    """A legacy backup format used in older versions. It's not recommended to use."""
    VERSION_12: _Format.ValueType  # 2
    """A new format recommended in most cases for fast backup and recovery."""
    AUTO: _Format.ValueType  # 3
    """Automatic version selection. Will be used version 12 unless the protection
    plan (policy) appends backups to the ones created by earlier product
    versions.
    """

class Format(_Format, metaclass=_FormatEnumTypeWrapper):
    """Format of the backup in policy. For backup locations that can be browsed
    with a file manager, the backup format determines the number of files and
    their extension.
    """

FORMAT_UNSPECIFIED: Format.ValueType  # 0
VERSION_11: Format.ValueType  # 1
"""A legacy backup format used in older versions. It's not recommended to use."""
VERSION_12: Format.ValueType  # 2
"""A new format recommended in most cases for fast backup and recovery."""
AUTO: Format.ValueType  # 3
"""Automatic version selection. Will be used version 12 unless the protection
plan (policy) appends backups to the ones created by earlier product
versions.
"""
global___Format = Format

@typing.final
class Policy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Policy ID."""
    name: builtins.str
    """Policy name."""
    enabled: builtins.bool
    """If this field is true, it means that the policy is enabled."""
    folder_id: builtins.str
    """ID of the folder that the policy belongs to."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def settings(self) -> global___PolicySettings:
        """Set of policy settings"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        enabled: builtins.bool = ...,
        settings: global___PolicySettings | None = ...,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "settings", b"settings", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "enabled", b"enabled", "folder_id", b"folder_id", "id", b"id", "name", b"name", "settings", b"settings", "updated_at", b"updated_at"]) -> None: ...

global___Policy = Policy

@typing.final
class PolicySettings(google.protobuf.message.Message):
    """Set of policy settings"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Compression:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _CompressionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PolicySettings._Compression.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        COMPRESSION_UNSPECIFIED: PolicySettings._Compression.ValueType  # 0
        NORMAL: PolicySettings._Compression.ValueType  # 1
        HIGH: PolicySettings._Compression.ValueType  # 2
        MAX: PolicySettings._Compression.ValueType  # 3
        OFF: PolicySettings._Compression.ValueType  # 4

    class Compression(_Compression, metaclass=_CompressionEnumTypeWrapper):
        """Compression rate of the backups."""

    COMPRESSION_UNSPECIFIED: PolicySettings.Compression.ValueType  # 0
    NORMAL: PolicySettings.Compression.ValueType  # 1
    HIGH: PolicySettings.Compression.ValueType  # 2
    MAX: PolicySettings.Compression.ValueType  # 3
    OFF: PolicySettings.Compression.ValueType  # 4

    class _RepeatePeriod:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RepeatePeriodEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PolicySettings._RepeatePeriod.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        REPEATE_PERIOD_UNSPECIFIED: PolicySettings._RepeatePeriod.ValueType  # 0
        HOURLY: PolicySettings._RepeatePeriod.ValueType  # 1
        DAILY: PolicySettings._RepeatePeriod.ValueType  # 2
        WEEKLY: PolicySettings._RepeatePeriod.ValueType  # 3
        MONTHLY: PolicySettings._RepeatePeriod.ValueType  # 4

    class RepeatePeriod(_RepeatePeriod, metaclass=_RepeatePeriodEnumTypeWrapper): ...
    REPEATE_PERIOD_UNSPECIFIED: PolicySettings.RepeatePeriod.ValueType  # 0
    HOURLY: PolicySettings.RepeatePeriod.ValueType  # 1
    DAILY: PolicySettings.RepeatePeriod.ValueType  # 2
    WEEKLY: PolicySettings.RepeatePeriod.ValueType  # 3
    MONTHLY: PolicySettings.RepeatePeriod.ValueType  # 4

    class _Day:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _DayEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PolicySettings._Day.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DAY_UNSPECIFIED: PolicySettings._Day.ValueType  # 0
        MONDAY: PolicySettings._Day.ValueType  # 1
        TUESDAY: PolicySettings._Day.ValueType  # 2
        WEDNESDAY: PolicySettings._Day.ValueType  # 3
        THURSDAY: PolicySettings._Day.ValueType  # 4
        FRIDAY: PolicySettings._Day.ValueType  # 5
        SATURDAY: PolicySettings._Day.ValueType  # 6
        SUNDAY: PolicySettings._Day.ValueType  # 7

    class Day(_Day, metaclass=_DayEnumTypeWrapper): ...
    DAY_UNSPECIFIED: PolicySettings.Day.ValueType  # 0
    MONDAY: PolicySettings.Day.ValueType  # 1
    TUESDAY: PolicySettings.Day.ValueType  # 2
    WEDNESDAY: PolicySettings.Day.ValueType  # 3
    THURSDAY: PolicySettings.Day.ValueType  # 4
    FRIDAY: PolicySettings.Day.ValueType  # 5
    SATURDAY: PolicySettings.Day.ValueType  # 6
    SUNDAY: PolicySettings.Day.ValueType  # 7

    class _ChangedBlockTracking:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ChangedBlockTrackingEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PolicySettings._ChangedBlockTracking.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CHANGED_BLOCK_TRACKING_UNSPECIFIED: PolicySettings._ChangedBlockTracking.ValueType  # 0
        USE_IF_ENABLED: PolicySettings._ChangedBlockTracking.ValueType  # 1
        ENABLE_AND_USE: PolicySettings._ChangedBlockTracking.ValueType  # 2
        DO_NOT_USE: PolicySettings._ChangedBlockTracking.ValueType  # 3

    class ChangedBlockTracking(_ChangedBlockTracking, metaclass=_ChangedBlockTrackingEnumTypeWrapper): ...
    CHANGED_BLOCK_TRACKING_UNSPECIFIED: PolicySettings.ChangedBlockTracking.ValueType  # 0
    USE_IF_ENABLED: PolicySettings.ChangedBlockTracking.ValueType  # 1
    ENABLE_AND_USE: PolicySettings.ChangedBlockTracking.ValueType  # 2
    DO_NOT_USE: PolicySettings.ChangedBlockTracking.ValueType  # 3

    @typing.final
    class Interval(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Type:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PolicySettings.Interval._Type.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            TYPE_UNSPECIFIED: PolicySettings.Interval._Type.ValueType  # 0
            SECONDS: PolicySettings.Interval._Type.ValueType  # 1
            MINUTES: PolicySettings.Interval._Type.ValueType  # 2
            HOURS: PolicySettings.Interval._Type.ValueType  # 3
            DAYS: PolicySettings.Interval._Type.ValueType  # 4
            WEEKS: PolicySettings.Interval._Type.ValueType  # 5
            MONTHS: PolicySettings.Interval._Type.ValueType  # 6

        class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
        TYPE_UNSPECIFIED: PolicySettings.Interval.Type.ValueType  # 0
        SECONDS: PolicySettings.Interval.Type.ValueType  # 1
        MINUTES: PolicySettings.Interval.Type.ValueType  # 2
        HOURS: PolicySettings.Interval.Type.ValueType  # 3
        DAYS: PolicySettings.Interval.Type.ValueType  # 4
        WEEKS: PolicySettings.Interval.Type.ValueType  # 5
        MONTHS: PolicySettings.Interval.Type.ValueType  # 6

        TYPE_FIELD_NUMBER: builtins.int
        COUNT_FIELD_NUMBER: builtins.int
        type: global___PolicySettings.Interval.Type.ValueType
        """A type of the interval."""
        count: builtins.int
        """The amount of value specified in `Interval.Type`."""
        def __init__(
            self,
            *,
            type: global___PolicySettings.Interval.Type.ValueType = ...,
            count: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["count", b"count", "type", b"type"]) -> None: ...

    @typing.final
    class RetriesConfiguration(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        INTERVAL_FIELD_NUMBER: builtins.int
        MAX_ATTEMPTS_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        """If true, enables retry on errors."""
        max_attempts: builtins.int
        """Max number of retry attempts. Operation will be considered as failed 
        when max number of retry attempts is reached.
        """
        @property
        def interval(self) -> global___PolicySettings.Interval:
            """An interval between retry attempts."""

        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            interval: global___PolicySettings.Interval | None = ...,
            max_attempts: builtins.int = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["interval", b"interval"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["enabled", b"enabled", "interval", b"interval", "max_attempts", b"max_attempts"]) -> None: ...

    @typing.final
    class Splitting(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        SIZE_FIELD_NUMBER: builtins.int
        size: builtins.int
        """The size of split backup file in bytes."""
        def __init__(
            self,
            *,
            size: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["size", b"size"]) -> None: ...

    @typing.final
    class VolumeShadowCopyServiceSettings(google.protobuf.message.Message):
        """Settings for Volume Shadow Copy Services which allows to notify
        VSS-aware applications that backup is about to start. This will
        ensure the consistent state of all data used by the applications.
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _VSSProvider:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _VSSProviderEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PolicySettings.VolumeShadowCopyServiceSettings._VSSProvider.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            VSS_PROVIDER_UNSPECIFIED: PolicySettings.VolumeShadowCopyServiceSettings._VSSProvider.ValueType  # 0
            NATIVE: PolicySettings.VolumeShadowCopyServiceSettings._VSSProvider.ValueType  # 1
            TARGET_SYSTEM_DEFINED: PolicySettings.VolumeShadowCopyServiceSettings._VSSProvider.ValueType  # 2

        class VSSProvider(_VSSProvider, metaclass=_VSSProviderEnumTypeWrapper): ...
        VSS_PROVIDER_UNSPECIFIED: PolicySettings.VolumeShadowCopyServiceSettings.VSSProvider.ValueType  # 0
        NATIVE: PolicySettings.VolumeShadowCopyServiceSettings.VSSProvider.ValueType  # 1
        TARGET_SYSTEM_DEFINED: PolicySettings.VolumeShadowCopyServiceSettings.VSSProvider.ValueType  # 2

        ENABLED_FIELD_NUMBER: builtins.int
        PROVIDER_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        """If true, the VSS will be enabled."""
        provider: global___PolicySettings.VolumeShadowCopyServiceSettings.VSSProvider.ValueType
        """A type of VSS provider to use in backup."""
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
            provider: global___PolicySettings.VolumeShadowCopyServiceSettings.VSSProvider.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["enabled", b"enabled", "provider", b"provider"]) -> None: ...

    @typing.final
    class ArchiveProperties(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        name: builtins.str
        """The name of the generated archive. The name may use the following variables: `[Machine Name]`, `[Plan ID]`, `[Plan Name]`, `[Unique ID]`, `[Virtualization Server Type]`.
        Default value: `[Machine Name]-[Plan ID]-[Unique ID]A`.
        """
        def __init__(
            self,
            *,
            name: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

    @typing.final
    class PerformanceWindow(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ENABLED_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        """If true, the time windows will be enabled."""
        def __init__(
            self,
            *,
            enabled: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["enabled", b"enabled"]) -> None: ...

    @typing.final
    class TimeOfDay(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        HOUR_FIELD_NUMBER: builtins.int
        MINUTE_FIELD_NUMBER: builtins.int
        hour: builtins.int
        """Hours."""
        minute: builtins.int
        """Minutes."""
        def __init__(
            self,
            *,
            hour: builtins.int = ...,
            minute: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["hour", b"hour", "minute", b"minute"]) -> None: ...

    @typing.final
    class Retention(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class RetentionRule(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            BACKUP_SET_FIELD_NUMBER: builtins.int
            MAX_AGE_FIELD_NUMBER: builtins.int
            MAX_COUNT_FIELD_NUMBER: builtins.int
            max_count: builtins.int
            @property
            def backup_set(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___PolicySettings.RepeatePeriod.ValueType]:
                """A list of backup sets where rules are effective."""

            @property
            def max_age(self) -> global___PolicySettings.Interval: ...
            def __init__(
                self,
                *,
                backup_set: collections.abc.Iterable[global___PolicySettings.RepeatePeriod.ValueType] | None = ...,
                max_age: global___PolicySettings.Interval | None = ...,
                max_count: builtins.int = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["condition", b"condition", "max_age", b"max_age", "max_count", b"max_count"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["backup_set", b"backup_set", "condition", b"condition", "max_age", b"max_age", "max_count", b"max_count"]) -> None: ...
            def WhichOneof(self, oneof_group: typing.Literal["condition", b"condition"]) -> typing.Literal["max_age", "max_count"] | None: ...

        RULES_FIELD_NUMBER: builtins.int
        BEFORE_BACKUP_FIELD_NUMBER: builtins.int
        before_backup: builtins.bool
        """If true, retention rules will be applied before backup is finished."""
        @property
        def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PolicySettings.Retention.RetentionRule]:
            """A list of retention rules."""

        def __init__(
            self,
            *,
            rules: collections.abc.Iterable[global___PolicySettings.Retention.RetentionRule] | None = ...,
            before_backup: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["before_backup", b"before_backup", "rules", b"rules"]) -> None: ...

    @typing.final
    class Scheduling(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Scheme:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _SchemeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PolicySettings.Scheduling._Scheme.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            SCHEME_UNSPECIFIED: PolicySettings.Scheduling._Scheme.ValueType  # 0
            SIMPLE: PolicySettings.Scheduling._Scheme.ValueType  # 1
            ALWAYS_FULL: PolicySettings.Scheduling._Scheme.ValueType  # 2
            ALWAYS_INCREMENTAL: PolicySettings.Scheduling._Scheme.ValueType  # 3
            WEEKLY_INCREMENTAL: PolicySettings.Scheduling._Scheme.ValueType  # 4
            WEEKLY_FULL_DAILY_INCREMENTAL: PolicySettings.Scheduling._Scheme.ValueType  # 5
            CUSTOM: PolicySettings.Scheduling._Scheme.ValueType  # 6
            """Custom will require to specify schedules for full, differential
            and incremental backups additionally.
            """
            CDP: PolicySettings.Scheduling._Scheme.ValueType  # 7

        class Scheme(_Scheme, metaclass=_SchemeEnumTypeWrapper):
            """Scheme of backups."""

        SCHEME_UNSPECIFIED: PolicySettings.Scheduling.Scheme.ValueType  # 0
        SIMPLE: PolicySettings.Scheduling.Scheme.ValueType  # 1
        ALWAYS_FULL: PolicySettings.Scheduling.Scheme.ValueType  # 2
        ALWAYS_INCREMENTAL: PolicySettings.Scheduling.Scheme.ValueType  # 3
        WEEKLY_INCREMENTAL: PolicySettings.Scheduling.Scheme.ValueType  # 4
        WEEKLY_FULL_DAILY_INCREMENTAL: PolicySettings.Scheduling.Scheme.ValueType  # 5
        CUSTOM: PolicySettings.Scheduling.Scheme.ValueType  # 6
        """Custom will require to specify schedules for full, differential
        and incremental backups additionally.
        """
        CDP: PolicySettings.Scheduling.Scheme.ValueType  # 7

        @typing.final
        class BackupSet(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _Type:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PolicySettings.Scheduling.BackupSet._Type.ValueType], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                TYPE_UNSPECIFIED: PolicySettings.Scheduling.BackupSet._Type.ValueType  # 0
                TYPE_AUTO: PolicySettings.Scheduling.BackupSet._Type.ValueType  # 1
                TYPE_FULL: PolicySettings.Scheduling.BackupSet._Type.ValueType  # 2
                TYPE_INCREMENTAL: PolicySettings.Scheduling.BackupSet._Type.ValueType  # 3
                TYPE_DIFFERENTIAL: PolicySettings.Scheduling.BackupSet._Type.ValueType  # 4

            class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
            TYPE_UNSPECIFIED: PolicySettings.Scheduling.BackupSet.Type.ValueType  # 0
            TYPE_AUTO: PolicySettings.Scheduling.BackupSet.Type.ValueType  # 1
            TYPE_FULL: PolicySettings.Scheduling.BackupSet.Type.ValueType  # 2
            TYPE_INCREMENTAL: PolicySettings.Scheduling.BackupSet.Type.ValueType  # 3
            TYPE_DIFFERENTIAL: PolicySettings.Scheduling.BackupSet.Type.ValueType  # 4

            @typing.final
            class Time(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                WEEKDAYS_FIELD_NUMBER: builtins.int
                REPEAT_AT_FIELD_NUMBER: builtins.int
                REPEAT_EVERY_FIELD_NUMBER: builtins.int
                TIME_FROM_FIELD_NUMBER: builtins.int
                TIME_TO_FIELD_NUMBER: builtins.int
                MONTHDAYS_FIELD_NUMBER: builtins.int
                INCLUDE_LAST_DAY_OF_MONTH_FIELD_NUMBER: builtins.int
                MONTHS_FIELD_NUMBER: builtins.int
                TYPE_FIELD_NUMBER: builtins.int
                include_last_day_of_month: builtins.bool
                """If set to true, last day of month will activate
                the policy.
                """
                type: global___PolicySettings.RepeatePeriod.ValueType
                """Possible types: `REPEATE_PERIOD_UNSPECIFIED`, `HOURLY`, `DAILY`, `WEEKLY`, `MONTHLY`."""
                @property
                def weekdays(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___PolicySettings.Day.ValueType]:
                    """Days in a week to perform a backup."""

                @property
                def repeat_at(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PolicySettings.TimeOfDay]:
                    """Time to repeat the backup."""

                @property
                def repeat_every(self) -> global___PolicySettings.Interval:
                    """Frequency of backup repetition."""

                @property
                def time_from(self) -> global___PolicySettings.TimeOfDay:
                    """The start time of the backup time interval."""

                @property
                def time_to(self) -> global___PolicySettings.TimeOfDay:
                    """The end time of the backup time interval."""

                @property
                def monthdays(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
                    """Days in a month to perform a backup.
                    Allowed values are from 1 to 31.
                    """

                @property
                def months(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
                    """Set of values. Allowed values form 1 to 12."""

                def __init__(
                    self,
                    *,
                    weekdays: collections.abc.Iterable[global___PolicySettings.Day.ValueType] | None = ...,
                    repeat_at: collections.abc.Iterable[global___PolicySettings.TimeOfDay] | None = ...,
                    repeat_every: global___PolicySettings.Interval | None = ...,
                    time_from: global___PolicySettings.TimeOfDay | None = ...,
                    time_to: global___PolicySettings.TimeOfDay | None = ...,
                    monthdays: collections.abc.Iterable[builtins.int] | None = ...,
                    include_last_day_of_month: builtins.bool = ...,
                    months: collections.abc.Iterable[builtins.int] | None = ...,
                    type: global___PolicySettings.RepeatePeriod.ValueType = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["repeat_every", b"repeat_every", "time_from", b"time_from", "time_to", b"time_to"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["include_last_day_of_month", b"include_last_day_of_month", "monthdays", b"monthdays", "months", b"months", "repeat_at", b"repeat_at", "repeat_every", b"repeat_every", "time_from", b"time_from", "time_to", b"time_to", "type", b"type", "weekdays", b"weekdays"]) -> None: ...

            @typing.final
            class SinceLastExecTime(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                DELAY_FIELD_NUMBER: builtins.int
                @property
                def delay(self) -> global___PolicySettings.Interval:
                    """The interval between backups."""

                def __init__(
                    self,
                    *,
                    delay: global___PolicySettings.Interval | None = ...,
                ) -> None: ...
                def HasField(self, field_name: typing.Literal["delay", b"delay"]) -> builtins.bool: ...
                def ClearField(self, field_name: typing.Literal["delay", b"delay"]) -> None: ...

            TIME_FIELD_NUMBER: builtins.int
            SINCE_LAST_EXEC_TIME_FIELD_NUMBER: builtins.int
            TYPE_FIELD_NUMBER: builtins.int
            type: global___PolicySettings.Scheduling.BackupSet.Type.ValueType
            """BackupSet type -- one of incr, full, differential or auto.
            if custom scheme is used the BackupSet type should be specified
            """
            @property
            def time(self) -> global___PolicySettings.Scheduling.BackupSet.Time: ...
            @property
            def since_last_exec_time(self) -> global___PolicySettings.Scheduling.BackupSet.SinceLastExecTime: ...
            def __init__(
                self,
                *,
                time: global___PolicySettings.Scheduling.BackupSet.Time | None = ...,
                since_last_exec_time: global___PolicySettings.Scheduling.BackupSet.SinceLastExecTime | None = ...,
                type: global___PolicySettings.Scheduling.BackupSet.Type.ValueType = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["setting", b"setting", "since_last_exec_time", b"since_last_exec_time", "time", b"time"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["setting", b"setting", "since_last_exec_time", b"since_last_exec_time", "time", b"time", "type", b"type"]) -> None: ...
            def WhichOneof(self, oneof_group: typing.Literal["setting", b"setting"]) -> typing.Literal["time", "since_last_exec_time"] | None: ...

        BACKUP_SETS_FIELD_NUMBER: builtins.int
        ENABLED_FIELD_NUMBER: builtins.int
        MAX_PARALLEL_BACKUPS_FIELD_NUMBER: builtins.int
        RAND_MAX_DELAY_FIELD_NUMBER: builtins.int
        SCHEME_FIELD_NUMBER: builtins.int
        WEEKLY_BACKUP_DAY_FIELD_NUMBER: builtins.int
        TASK_FAILURE_FIELD_NUMBER: builtins.int
        enabled: builtins.bool
        """If true, the backup schedule will be enabled."""
        max_parallel_backups: builtins.int
        """Max number of backup processes allowed to run in parallel. Unlimited if not set."""
        scheme: global___PolicySettings.Scheduling.Scheme.ValueType
        """A backup scheme. Available values: `simple`, `always_full`, `always_incremental`, `weekly_incremental`, `weekly_full_daily_incremental`, `custom`, `cdp`."""
        weekly_backup_day: global___PolicySettings.Day.ValueType
        """A day of week to start weekly backups."""
        @property
        def backup_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PolicySettings.Scheduling.BackupSet]:
            """A list of schedules with backup sets that compose the whole scheme."""

        @property
        def rand_max_delay(self) -> global___PolicySettings.Interval:
            """Configuration of the random delay between the execution of parallel tasks."""

        @property
        def task_failure(self) -> global___PolicySettings.RetriesConfiguration:
            """Task failure settings in case of failure of scheduled task, not applicable to  manually launched tasks"""

        def __init__(
            self,
            *,
            backup_sets: collections.abc.Iterable[global___PolicySettings.Scheduling.BackupSet] | None = ...,
            enabled: builtins.bool = ...,
            max_parallel_backups: builtins.int = ...,
            rand_max_delay: global___PolicySettings.Interval | None = ...,
            scheme: global___PolicySettings.Scheduling.Scheme.ValueType = ...,
            weekly_backup_day: global___PolicySettings.Day.ValueType = ...,
            task_failure: global___PolicySettings.RetriesConfiguration | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["rand_max_delay", b"rand_max_delay", "task_failure", b"task_failure"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["backup_sets", b"backup_sets", "enabled", b"enabled", "max_parallel_backups", b"max_parallel_backups", "rand_max_delay", b"rand_max_delay", "scheme", b"scheme", "task_failure", b"task_failure", "weekly_backup_day", b"weekly_backup_day"]) -> None: ...

    @typing.final
    class FileFilters(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        EXCLUSION_MASKS_FIELD_NUMBER: builtins.int
        INCLUSION_MASKS_FIELD_NUMBER: builtins.int
        @property
        def exclusion_masks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Do not backup files that match the following criteria"""

        @property
        def inclusion_masks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Backup only files that match the following criteria"""

        def __init__(
            self,
            *,
            exclusion_masks: collections.abc.Iterable[builtins.str] | None = ...,
            inclusion_masks: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["exclusion_masks", b"exclusion_masks", "inclusion_masks", b"inclusion_masks"]) -> None: ...

    COMPRESSION_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    MULTI_VOLUME_SNAPSHOTTING_ENABLED_FIELD_NUMBER: builtins.int
    PRESERVE_FILE_SECURITY_SETTINGS_FIELD_NUMBER: builtins.int
    REATTEMPTS_FIELD_NUMBER: builtins.int
    SILENT_MODE_ENABLED_FIELD_NUMBER: builtins.int
    SPLITTING_FIELD_NUMBER: builtins.int
    VM_SNAPSHOT_REATTEMPTS_FIELD_NUMBER: builtins.int
    VSS_FIELD_NUMBER: builtins.int
    ARCHIVE_FIELD_NUMBER: builtins.int
    PERFORMANCE_WINDOW_FIELD_NUMBER: builtins.int
    RETENTION_FIELD_NUMBER: builtins.int
    SCHEDULING_FIELD_NUMBER: builtins.int
    CBT_FIELD_NUMBER: builtins.int
    FAST_BACKUP_ENABLED_FIELD_NUMBER: builtins.int
    QUIESCE_SNAPSHOTTING_ENABLED_FIELD_NUMBER: builtins.int
    FILE_FILTERS_FIELD_NUMBER: builtins.int
    compression: global___PolicySettings.Compression.ValueType
    """Archive compression level."""
    format: global___Format.ValueType
    """Format of the Cyberprotect backup archive."""
    multi_volume_snapshotting_enabled: builtins.bool
    """If true, snapshots of multiple volumes will be taken simultaneously."""
    preserve_file_security_settings: builtins.bool
    """If true, the file security settings will be preserved."""
    silent_mode_enabled: builtins.bool
    """If true, a user interaction will be avoided when possible. Equals to false if value is not specified."""
    cbt: global___PolicySettings.ChangedBlockTracking.ValueType
    """A configuration of Changed Block Tracking (CBT)."""
    fast_backup_enabled: builtins.bool
    """If true, determines whether a file has changed by the file size and timestamp. Otherwise, the entire file contents are compared to those stored in the backup."""
    quiesce_snapshotting_enabled: builtins.bool
    """If true, a quiesced snapshot of the virtual machine will be taken."""
    @property
    def reattempts(self) -> global___PolicySettings.RetriesConfiguration:
        """Configuration of retries on recoverable errors during the backup operations like reconnection to destination. No attempts to fix recoverable errors will be made if retry configuration is not set."""

    @property
    def splitting(self) -> global___PolicySettings.Splitting:
        """Determines the size to split backups on. Splitting is not performed if value is not specified."""

    @property
    def vm_snapshot_reattempts(self) -> global___PolicySettings.RetriesConfiguration:
        """Configuration of retries on errors during the creation of the virtual machine snapshot. No attempts to fix recoverable errors will be made if retry configuration is not set."""

    @property
    def vss(self) -> global___PolicySettings.VolumeShadowCopyServiceSettings:
        """Settings for the Volume Shadow Copy Service (VSS) provider. If not set, no VSS provider is used."""

    @property
    def archive(self) -> global___PolicySettings.ArchiveProperties:
        """The archive properties."""

    @property
    def performance_window(self) -> global___PolicySettings.PerformanceWindow:
        """Time windows for performance limitations of backup and storage maintenance operations."""

    @property
    def retention(self) -> global___PolicySettings.Retention:
        """Configuration of backup retention rules."""

    @property
    def scheduling(self) -> global___PolicySettings.Scheduling:
        """Configuration of the backup schedule."""

    @property
    def file_filters(self) -> global___PolicySettings.FileFilters:
        """File filters to specify masks of files to backup or to exclude of backuping"""

    def __init__(
        self,
        *,
        compression: global___PolicySettings.Compression.ValueType = ...,
        format: global___Format.ValueType = ...,
        multi_volume_snapshotting_enabled: builtins.bool = ...,
        preserve_file_security_settings: builtins.bool = ...,
        reattempts: global___PolicySettings.RetriesConfiguration | None = ...,
        silent_mode_enabled: builtins.bool = ...,
        splitting: global___PolicySettings.Splitting | None = ...,
        vm_snapshot_reattempts: global___PolicySettings.RetriesConfiguration | None = ...,
        vss: global___PolicySettings.VolumeShadowCopyServiceSettings | None = ...,
        archive: global___PolicySettings.ArchiveProperties | None = ...,
        performance_window: global___PolicySettings.PerformanceWindow | None = ...,
        retention: global___PolicySettings.Retention | None = ...,
        scheduling: global___PolicySettings.Scheduling | None = ...,
        cbt: global___PolicySettings.ChangedBlockTracking.ValueType = ...,
        fast_backup_enabled: builtins.bool = ...,
        quiesce_snapshotting_enabled: builtins.bool = ...,
        file_filters: global___PolicySettings.FileFilters | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["archive", b"archive", "file_filters", b"file_filters", "performance_window", b"performance_window", "reattempts", b"reattempts", "retention", b"retention", "scheduling", b"scheduling", "splitting", b"splitting", "vm_snapshot_reattempts", b"vm_snapshot_reattempts", "vss", b"vss"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["archive", b"archive", "cbt", b"cbt", "compression", b"compression", "fast_backup_enabled", b"fast_backup_enabled", "file_filters", b"file_filters", "format", b"format", "multi_volume_snapshotting_enabled", b"multi_volume_snapshotting_enabled", "performance_window", b"performance_window", "preserve_file_security_settings", b"preserve_file_security_settings", "quiesce_snapshotting_enabled", b"quiesce_snapshotting_enabled", "reattempts", b"reattempts", "retention", b"retention", "scheduling", b"scheduling", "silent_mode_enabled", b"silent_mode_enabled", "splitting", b"splitting", "vm_snapshot_reattempts", b"vm_snapshot_reattempts", "vss", b"vss"]) -> None: ...

global___PolicySettings = PolicySettings

@typing.final
class PolicyApplication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PolicyApplication._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: PolicyApplication._Status.ValueType  # 0
        OK: PolicyApplication._Status.ValueType  # 1
        """Application is applied and everything is OK."""
        RUNNING: PolicyApplication._Status.ValueType  # 2
        """Application is currently running."""
        DISABLED: PolicyApplication._Status.ValueType  # 3
        """Application is disabled."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: PolicyApplication.Status.ValueType  # 0
    OK: PolicyApplication.Status.ValueType  # 1
    """Application is applied and everything is OK."""
    RUNNING: PolicyApplication.Status.ValueType  # 2
    """Application is currently running."""
    DISABLED: PolicyApplication.Status.ValueType  # 3
    """Application is disabled."""

    POLICY_ID_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    IS_PROCESSING_FIELD_NUMBER: builtins.int
    policy_id: builtins.str
    """Policy ID."""
    compute_instance_id: builtins.str
    """Compute Cloud instance ID."""
    enabled: builtins.bool
    status: global___PolicyApplication.Status.ValueType
    is_processing: builtins.bool
    """If true, then the policy is in in the process of binding to the instance."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        policy_id: builtins.str = ...,
        compute_instance_id: builtins.str = ...,
        enabled: builtins.bool = ...,
        status: global___PolicyApplication.Status.ValueType = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        is_processing: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "created_at", b"created_at", "enabled", b"enabled", "is_processing", b"is_processing", "policy_id", b"policy_id", "status", b"status"]) -> None: ...

global___PolicyApplication = PolicyApplication



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.mdb.spqr.v1.database_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetDatabaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the SPQR cluster that the database belongs to.
    To get the cluster ID use a [ClusterService.List] request.
    """
    database_name: builtins.str
    """Name of the SPQR database to return.
    To get the name of the database use a [DatabaseService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_name", b"database_name"]) -> None: ...

global___GetDatabaseRequest = GetDatabaseRequest

@typing.final
class ListDatabasesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the SPQR cluster to list databases in.
    To get the cluster ID, use a [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListDatabasesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListDatabasesResponse.next_page_token] returned by the previous list request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDatabasesRequest = ListDatabasesRequest

@typing.final
class ListDatabasesAtRevisionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the SPQR cluster to list databases in.
    To get the cluster ID, use a [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListDatabasesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListDatabasesResponse.next_page_token] returned by the previous list request.
    """
    revision: builtins.int
    """Cluster revision"""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        revision: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token", "revision", b"revision"]) -> None: ...

global___ListDatabasesAtRevisionRequest = ListDatabasesAtRevisionRequest

@typing.final
class ListDatabasesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListDatabasesRequest.page_size], use the [next_page_token] as the value
    for the [ListDatabasesRequest.page_token] parameter in the next list request. Each subsequent
    list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def databases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.spqr.v1.database_pb2.Database]:
        """List of SPQR databases."""

    def __init__(
        self,
        *,
        databases: collections.abc.Iterable[yandex.cloud.mdb.spqr.v1.database_pb2.Database] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["databases", b"databases", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDatabasesResponse = ListDatabasesResponse

@typing.final
class CreateDatabaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_SPEC_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the SPQR cluster to create a database in.
    To get the cluster ID, use a [ClusterService.List] request.
    """
    @property
    def database_spec(self) -> yandex.cloud.mdb.spqr.v1.database_pb2.DatabaseSpec:
        """Configuration of the database to create."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_spec: yandex.cloud.mdb.spqr.v1.database_pb2.DatabaseSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["database_spec", b"database_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_spec", b"database_spec"]) -> None: ...

global___CreateDatabaseRequest = CreateDatabaseRequest

@typing.final
class CreateDatabaseMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the SPQR cluster where the database is being created."""
    database_name: builtins.str
    """Name of the SPQR database that is being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_name", b"database_name"]) -> None: ...

global___CreateDatabaseMetadata = CreateDatabaseMetadata

@typing.final
class DeleteDatabaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the SPQR cluster to delete the database in.
    To get the cluster ID, use a [ClusterService.List] request.
    """
    database_name: builtins.str
    """Name of the database to delete.
    To get the name of the database, use a [DatabaseService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_name", b"database_name"]) -> None: ...

global___DeleteDatabaseRequest = DeleteDatabaseRequest

@typing.final
class DeleteDatabaseMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the SPQR cluster where the database is being deleted."""
    database_name: builtins.str
    """Name of the SPQR database that is being deleted."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_name", b"database_name"]) -> None: ...

global___DeleteDatabaseMetadata = DeleteDatabaseMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.iam.v1.api_key_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetApiKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_KEY_ID_FIELD_NUMBER: builtins.int
    api_key_id: builtins.str
    """ID of the API key to return.
    To get the API key ID, use a [ApiKeyService.List] request.
    """
    def __init__(
        self,
        *,
        api_key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["api_key_id", b"api_key_id"]) -> None: ...

global___GetApiKeyRequest = GetApiKeyRequest

@typing.final
class ListApiKeysRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    service_account_id: builtins.str
    """ID of the service account to list API keys for.
    To get the service account ID, use a [yandex.cloud.iam.v1.ServiceAccountService.List] request.
    If not specified, it defaults to the subject that made the request.
    use current subject identity if this not set
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListApiKeysResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListApiKeysResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        service_account_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "service_account_id", b"service_account_id"]) -> None: ...

global___ListApiKeysRequest = ListApiKeysRequest

@typing.final
class ListApiKeysResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_KEYS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListApiKeysRequest.page_size], use
    the [next_page_token] as the value
    for the [ListApiKeysRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def api_keys(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.iam.v1.api_key_pb2.ApiKey]:
        """List of API keys."""

    def __init__(
        self,
        *,
        api_keys: collections.abc.Iterable[yandex.cloud.iam.v1.api_key_pb2.ApiKey] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["api_keys", b"api_keys", "next_page_token", b"next_page_token"]) -> None: ...

global___ListApiKeysResponse = ListApiKeysResponse

@typing.final
class CreateApiKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    SCOPES_FIELD_NUMBER: builtins.int
    EXPIRES_AT_FIELD_NUMBER: builtins.int
    service_account_id: builtins.str
    """ID of the service account to create an API key for.
    To get the service account ID, use a [yandex.cloud.iam.v1.ServiceAccountService.List] request.
    If not specified, it defaults to the subject that made the request.
    use current subject identity if this not set
    """
    description: builtins.str
    """Description of the API key."""
    scope: builtins.str
    """Scope of the API key."""
    @property
    def scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Scopes of the API key."""

    @property
    def expires_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """API key expiration timestamp, if not specified, then the API key doesn't expire"""

    def __init__(
        self,
        *,
        service_account_id: builtins.str = ...,
        description: builtins.str = ...,
        scope: builtins.str = ...,
        scopes: collections.abc.Iterable[builtins.str] | None = ...,
        expires_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expires_at", b"expires_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "expires_at", b"expires_at", "scope", b"scope", "scopes", b"scopes", "service_account_id", b"service_account_id"]) -> None: ...

global___CreateApiKeyRequest = CreateApiKeyRequest

@typing.final
class CreateApiKeyResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_KEY_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    secret: builtins.str
    """Secret part of the API key. This secret key you may use in the requests for authentication."""
    @property
    def api_key(self) -> yandex.cloud.iam.v1.api_key_pb2.ApiKey:
        """ApiKey resource."""

    def __init__(
        self,
        *,
        api_key: yandex.cloud.iam.v1.api_key_pb2.ApiKey | None = ...,
        secret: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["api_key", b"api_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["api_key", b"api_key", "secret", b"secret"]) -> None: ...

global___CreateApiKeyResponse = CreateApiKeyResponse

@typing.final
class UpdateApiKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_KEY_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SCOPES_FIELD_NUMBER: builtins.int
    EXPIRES_AT_FIELD_NUMBER: builtins.int
    api_key_id: builtins.str
    """ID of the ApiKey resource to update.
    To get the API key ID, use a [ApiKeyService.List] request.
    """
    description: builtins.str
    """Description of the API key."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the ApiKey resource are going to be updated."""

    @property
    def scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Scopes of the API key."""

    @property
    def expires_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """API key expiration timestamp, if not specified, then the API key doesn't expire"""

    def __init__(
        self,
        *,
        api_key_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        description: builtins.str = ...,
        scopes: collections.abc.Iterable[builtins.str] | None = ...,
        expires_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expires_at", b"expires_at", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["api_key_id", b"api_key_id", "description", b"description", "expires_at", b"expires_at", "scopes", b"scopes", "update_mask", b"update_mask"]) -> None: ...

global___UpdateApiKeyRequest = UpdateApiKeyRequest

@typing.final
class UpdateApiKeyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_KEY_ID_FIELD_NUMBER: builtins.int
    api_key_id: builtins.str
    """ID of the ApiKey resource that is being updated."""
    def __init__(
        self,
        *,
        api_key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["api_key_id", b"api_key_id"]) -> None: ...

global___UpdateApiKeyMetadata = UpdateApiKeyMetadata

@typing.final
class DeleteApiKeyRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_KEY_ID_FIELD_NUMBER: builtins.int
    api_key_id: builtins.str
    """ID of the API key to delete.
    To get the API key ID, use a [ApiKeyService.List] request.
    """
    def __init__(
        self,
        *,
        api_key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["api_key_id", b"api_key_id"]) -> None: ...

global___DeleteApiKeyRequest = DeleteApiKeyRequest

@typing.final
class DeleteApiKeyMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_KEY_ID_FIELD_NUMBER: builtins.int
    api_key_id: builtins.str
    """ID of the API key that is being deleted."""
    def __init__(
        self,
        *,
        api_key_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["api_key_id", b"api_key_id"]) -> None: ...

global___DeleteApiKeyMetadata = DeleteApiKeyMetadata

@typing.final
class ListApiKeyOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_KEY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    api_key_id: builtins.str
    """ID of the key to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListApiKeyOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListApiKeyOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        api_key_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["api_key_id", b"api_key_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListApiKeyOperationsRequest = ListApiKeyOperationsRequest

@typing.final
class ListApiKeyOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListApiKeyOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListApiKeyOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified API key."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListApiKeyOperationsResponse = ListApiKeyOperationsResponse

@typing.final
class ListApiKeyScopesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListApiKeyScopesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListApiKeyScopesResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListApiKeyScopesRequest = ListApiKeyScopesRequest

@typing.final
class ListApiKeyScopesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCOPES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListApiKeyScopesRequest.page_size], use the [next_page_token] as the value
    for the [ListApiKeyScopesRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of scopes"""

    def __init__(
        self,
        *,
        scopes: collections.abc.Iterable[builtins.str] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "scopes", b"scopes"]) -> None: ...

global___ListApiKeyScopesResponse = ListApiKeyScopesResponse
